@@ -6,7 +6,9 @@
 #include <QKeyEvent>
 #include <QButtonGroup>
 
+#include <QX11Info>
 #include <X11/Xlib.h>
+#include <X11/Xatom.h>
 
 class BindButton : public QMaemo5ValueButton
 {
@@ -21,6 +23,7 @@ private:
     int code;
 
     void setKeyCode(int code);
+    void grabZoomKeys(bool grab);
 
     void keyPressEvent(QKeyEvent *e);
     void contextMenuEvent(QContextMenuEvent*);
